import { LitElement } from 'lit';
import { HslaColor } from 'colord';
import type { UUIColorAreaEvent } from '@umbraco-ui/uui-color-area/lib';
import type { UUIColorSliderEvent } from '@umbraco-ui/uui-color-slider/lib';
import type { UUIColorSwatchesEvent } from '@umbraco-ui/uui-color-swatches/lib';
export type UUIColorPickerFormat = 'hex' | 'rgb' | 'hsl' | 'hsv';
export type UUIColorPickerFormatWithAlpha = UUIColorPickerFormat | 'hexa' | 'rgba' | 'hsla' | 'hsva';
type UUIColorPickerSize = 'small' | 'medium' | 'large';
declare const UUIColorPickerElement_base: (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").LabelMixinInterface) & typeof LitElement;
/**
 * @element uui-color-picker
 * @cssprop --uui-color-picker-width - The width of the color picker
 * @description
 * @fires {UUIColorPickerChangeEvent} change - Fired when the color changes
 */
export declare class UUIColorPickerElement extends UUIColorPickerElement_base {
    private _input;
    private _previewButton;
    private _swatches;
    private _value;
    private inputValue;
    private hue;
    private saturation;
    private lightness;
    private alpha;
    private _colord;
    /**
     * The current color.
     * @attr
     * @type {string}
     * @default ''
     **/
    set value(value: string);
    get value(): string;
    /**
     * The format to use for the display value. If opacity is enabled, these will translate to HEXA, RGBA, HSLA, and HSVA
     * respectively. The color picker will always accept user input in any format (including CSS color names) and convert
     * it to the desired format.
     * @attr
     * @type {UUIColorPickerFormat}
     * @default 'hex'
     */
    format: UUIColorPickerFormat;
    /**
     * The input's name attribute.
     * @attr
     * @type {string}
     * @default ''
     **/
    name: string;
    /**
     * Determines the size of the color picker's trigger. This has no effect on inline color pickers.
     * @attr
     * @type {UUIColorPickerSize}
     * @default 'medium'
     **/
    size: UUIColorPickerSize;
    /**
     * Removes the format toggle.
     * @attr
     * @type {boolean}
     * @default false
     **/
    noFormatToggle: boolean;
    /**
     * Renders the color picker inline rather than inside a dropdown.
     * @attr
     * @type {boolean}
     * @default false
     **/
    inline: boolean;
    /**
     * Sets the color picker to disabled.
     * @attr
     * @type {boolean}
     * @default false
     **/
    disabled: boolean;
    /**
     * Whether to show the opacity slider.
     * @attr
     * @type {boolean}
     * @default false
     **/
    opacity: boolean;
    /**
     * Sets the color picker to readonly mode.
     * @type {boolean}
     * @attr
     * @default false
     */
    readonly: boolean;
    /**
     * By default, the value will be set in lowercase. Set this to true to set it in uppercase instead.
     * @attr
     * @type {boolean}
     * @default false
     **/
    uppercase: boolean;
    /**
     * An array of predefined color swatches to display. Can include any format the color picker can parse, including
     * HEX(A), RGB(A), HSL(A), HSV(A), and CSS color names.
     */
    swatches: string[];
    connectedCallback(): void;
    /** Returns the current value as a string in the specified format. */
    getFormattedValue(format: UUIColorPickerFormat): string;
    getBrightness(lightness: number): number;
    getLightness(brightness: number): number;
    handleFormatToggle(): void;
    handleAlphaChange(event: UUIColorSliderEvent): void;
    handleHueChange(event: UUIColorSliderEvent): void;
    handleGridChange(event: UUIColorAreaEvent): void;
    handleInputChange(event: CustomEvent): void;
    handleInputKeyDown(event: KeyboardEvent): void;
    handleColorSwatchChange(event: UUIColorSwatchesEvent): void;
    handleCopy(): void;
    handleEyeDropper(): void;
    setColor(colorString: string | HslaColor): true | undefined;
    setLetterCase(string: string): string;
    /** Generates a hex string from HSL values. Hue must be 0-360. All other arguments must be 0-100. */
    private getHexString;
    private _syncValues;
    private _renderColorPicker;
    private _renderSwatches;
    private _renderPreviewButton;
    render(): import("lit-html").TemplateResult<1>;
    static styles: import("lit").CSSResult[];
}
declare global {
    interface HTMLElementTagNameMap {
        'uui-color-picker': UUIColorPickerElement;
    }
}
export {};
